EnxSetting class

Mixed-in types

Properties

audioViewConfig EnxAudioViewConfig
getter/setter pair
bottomList Set<BottomOption>
getter/setter pair
broadcastStream StreamController<Map<String, dynamic>?>
final
containers bool
getter/setter pair
enxRequiredList Set<EnxRequiredEventsOption>
getter/setter pair
extraButtons Set<Widget>
final
getClientId String
getter/setter pair
groupName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAudio bool
getter/setter pair
isAudioMute bool
getter/setter pair
isAudioOnlyCalls bool
getter/setter pair
isAudioOnlyView bool
getter/setter pair
isAudioSwitch bool
getter/setter pair
isCameraSwitch bool
getter/setter pair
isCaptureAutoSave bool
getter/setter pair
isChat bool
getter/setter pair
isConfirmation bool
getter/setter pair
isDisconnect bool
getter/setter pair
isFontCamera bool
getter/setter pair
isLiveStreamingRunning bool
getter/setter pair
isRTMPStartAfterJoin bool
getter/setter pair
isStart bool
getter/setter pair
isUserAwaited bool
getter/setter pair
isVideo bool
getter/setter pair
isVideoMute bool
getter/setter pair
joinText String
getter/setter pair
liveStreamInfo Map<String, dynamic>
getter/setter pair
getter/setter pair
optionsData Map
getter/setter pair
participantListOption Set<ParticipantListOption>
getter/setter pair
participantsLists List<Map<String, dynamic>>
getter/setter pair
roomMode String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showGoLiveIndicator bool
getter/setter pair
topList Set<TopOption>
getter/setter pair
urlDetails String
getter/setter pair
userRole String
getter/setter pair
visualBuilder Map
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
closeChatPage() → void
configureAudioViewConfig(EnxAudioViewConfig? config) → void
configureParticipantList(ParticipantListOption btn) → void
configureRequiredEventList(Set<EnxRequiredEventsOption> btn) → void
createExtraButton(List<Widget> btn) → void
disconnectRoom() Future<void>
dispose() → void
Discards any resources used by the object.
inherited
getCurrentRole() String
getEmbedSetting({required String embedUrl}) → void
getEnxRequiredEventList() Set<EnxRequiredEventsOption>
getExtraButtons() Set<Widget>
getisUserAwaited() bool
getMenuOptionList() Set<MenuOption>
getParticipantOptionList() Set<ParticipantListOption>
getParticipantsList() List<Map<String, dynamic>>
getRoomMode() String
getScreenShare(bool isScreen) → void
getSelfClientId(String id) → void
getTopOptionList() Set<TopOption>
isAudioOnlyCall(bool isEnable) → void
isAudioOnlyViewMode(bool isEnable) → void
isCaptchaAutoSave(bool isAutosave) → void
isPreScreening(bool isEnable) → void
isShowGoLiveIndicator(bool isStart) → void
joinAsAudioMute(bool isEnable) → void
joinAsVideoMute(bool isEnable) → void
liveStreamingInformation(Map<String, dynamic> streamInfo) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resetAudioViewConfig() → void
sendUserData(EnxSendUserDataModel userDataModel) → void
setCameraPosition(bool isFontCamera) → void
setGroupName(String grpName) String
setJoinText(String jointext) → void
setParticipantList(List<UserModel> participantList) → void
setRTMPCustomUrlDetails(String url) → void
startLiveStreamingAfterJoin(bool isStart) → void
startShare(bool value) → void
startStreaming(Map<String, dynamic> streamInfo) → void
stopStreaming() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EnxSetting
no setter